class PigmentError(Exception):
    """The base class for all Pigment exceptions"""

    pass


class WrongLengthError(PigmentError, ValueError):
    """The argument provided had an invalid length

    Note:
        Also a subclass of ``ValueError``

    Attributes:
        argument (str): The name of the argument
    """

    def __init__(self, argument: str = None):
        if argument:
            super().__init__(f"argument {argument} has an invalid length")
        else:
            super().__init__(f"argument has an invalid length")


class InvalidRGBValue(PigmentError, ValueError):
    """A value was invalid when converting or saving a color in RGB form

    Note:
        Also a subclass of ``ValueError``
    """

    def __init__(self):
        super().__init__("invalid RGB value")



from pathlib import Path

import setuptools

long_description = (Path(__file__).parent / "README.md").read_text()

setuptools.setup(
    name="pigment",
    version="0.2.0",
    author="Ben Soyka",
    author_email="bensoyka@icloud.com",
    description="Python utilities for colors",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/bsoyka/pigment",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
    project_urls={
        "Documentation": "https://pigment.readthedocs.io/",
        "Changelog": "https://github.com/bsoyka/pigment/releases",
    },
)
